translate.storage.properties.DialectJava

Package translate :: Package storage :: Module properties :: Class DialectJava |
[hide private]
[frames] | no frames]

# Class DialectJava

source code

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `Dialect`: `encode`, `find_delimiter`, `key_strip`, `value_strip`

Class Variables | [hide private]
| name = `"java"` Parse an instance of this class from the start of the given string.
| default_encoding = `"iso-8859-1"`
| delimiters = `[u"=", u":", u" "]` Parse an instance of this class from the start of the given string.
Inherited from `Dialect`: `key_wrap_char`, `pair_terminator`, `value_wrap_char`

Properties | [hide private]
Inherited from `object`: `__class__`